@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2019-2021 Andreas Motl <andreas@hiveeyes.org>
+# (c) 2019-2022 Andreas Motl <andreas@hiveeyes.org>
 # License: GNU Affero General Public License, Version 3
 import asyncio
 import dataclasses
@@ -12,6 +12,8 @@ from urllib.parse import urljoin, urlparse
 import colored
 import requests
 import requests_cache
+from grafana_client.api import GrafanaApi
+from grafana_client.client import GrafanaClientError, GrafanaUnauthorizedError
 from munch import Munch, munchify
 from tqdm import tqdm
 
@@ -22,15 +24,6 @@ from grafana_wtf.model import (
     DatasourceItem,
     GrafanaDataModel,
 )
-from grafana_wtf.monkey import monkeypatch_grafana_client
-
-# Apply monkeypatch to `grafana-client`.
-# https://github.com/m0nhawk/grafana_api/pull/85/files
-monkeypatch_grafana_client()
-
-from grafana_client.api import GrafanaApi
-from grafana_client.client import GrafanaClientError, GrafanaUnauthorizedError
-
 from grafana_wtf.util import JsonPathFinder
 
 log = logging.getLogger(__name__)
@@ -151,7 +144,7 @@ class GrafanaEngine:
         log.info("Scanning datasources")
         try:
             self.data.datasources = munchify(self.grafana.datasource.list_datasources())
-            log.info("Found {} data sources".format(len(self.data.datasources)))
+            log.info("Found {} data source(s)".format(len(self.data.datasources)))
             return self.data.datasources
         except GrafanaClientError as ex:
             message = "{name}: {ex}".format(name=ex.__class__.__name__, ex=ex)
@@ -178,7 +171,7 @@ class GrafanaEngine:
                         continue
             else:
                 self.data.dashboard_list = self.grafana.search.search_dashboards(limit=5000)
-            log.info("Found {} dashboards".format(len(self.data.dashboard_list)))
+            log.info("Found {} dashboard(s)".format(len(self.data.dashboard_list)))
 
         except GrafanaClientError as ex:
             self.handle_grafana_error(ex)
@@ -302,6 +295,17 @@ class GrafanaWtf(GrafanaEngine):
 
         return response
 
+    def version(self):
+
+        try:
+            health = self.grafana.client.GET("/health")
+        except Exception as ex:
+            log.error(f"Request to /health endpoint failed: {ex}")
+            health = {}
+
+        version = health.get("version")
+        return version
+
     def dashboard_details(self):
         for dashboard in self.data.dashboards:
             yield DashboardDetails(dashboard=dashboard)
@@ -491,7 +495,7 @@ class Indexer:
                     ds = dict(ds)
                 if ds not in items:
                     items.append(ds)
-        return sorted(items)
+        return items
 
     def index_dashboards(self):
 
